notetools.NoteHead
==================

.. inheritance-diagram:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead
   :private-bases:

.. autoclass:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.lilypond_format

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.named_chromatic_pitch

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.tweak

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.is_cautionary

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.is_forced

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.written_pitch

Special Methods
---------------

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__eq__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__ge__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__gt__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__le__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__lt__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__ne__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__repr__

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__str__
